@@ -16,7 +16,7 @@ var searchData=
   ['calendarfieldindex_2eidl_13',['CalendarFieldIndex.idl',['../CalendarFieldIndex_8idl.html',1,'']]],
   ['calendaritem_2eidl_14',['CalendarItem.idl',['../CalendarItem_8idl.html',1,'']]],
   ['calendaritem2_2eidl_15',['CalendarItem2.idl',['../CalendarItem2_8idl.html',1,'']]],
-  ['callablestatement_2eidl_16',['callablestatement.idl',['../sdb_2CallableStatement_8idl.html',1,'(Global Namespace)'],['../sdbc_2CallableStatement_8idl.html',1,'(Global Namespace)']]],
+  ['callablestatement_2eidl_16',['CallableStatement.idl',['../sdb_2CallableStatement_8idl.html',1,'(Global Namespace)'],['../sdbc_2CallableStatement_8idl.html',1,'(Global Namespace)']]],
   ['camerageometry_2eidl_17',['CameraGeometry.idl',['../CameraGeometry_8idl.html',1,'']]],
   ['candlestickcharttype_2eidl_18',['CandleStickChartType.idl',['../CandleStickChartType_8idl.html',1,'']]],
   ['cannotactivatefactoryexception_2eidl_19',['CannotActivateFactoryException.idl',['../CannotActivateFactoryException_8idl.html',1,'']]],
@@ -35,7 +35,7 @@ var searchData=
   ['cartesiancoordinatesystem2d_2eidl_32',['CartesianCoordinateSystem2d.idl',['../CartesianCoordinateSystem2d_8idl.html',1,'']]],
   ['cartesiancoordinatesystem3d_2eidl_33',['CartesianCoordinateSystem3d.idl',['../CartesianCoordinateSystem3d_8idl.html',1,'']]],
   ['casemap_2eidl_34',['CaseMap.idl',['../CaseMap_8idl.html',1,'']]],
-  ['cell_2eidl_35',['cell.idl',['../text_2Cell_8idl.html',1,'(Global Namespace)'],['../table_2Cell_8idl.html',1,'(Global Namespace)']]],
+  ['cell_2eidl_35',['Cell.idl',['../table_2Cell_8idl.html',1,'(Global Namespace)'],['../text_2Cell_8idl.html',1,'(Global Namespace)']]],
   ['celladdress_2eidl_36',['CellAddress.idl',['../CellAddress_8idl.html',1,'']]],
   ['cellannotation_2eidl_37',['CellAnnotation.idl',['../CellAnnotation_8idl.html',1,'']]],
   ['cellannotations_2eidl_38',['CellAnnotations.idl',['../CellAnnotations_8idl.html',1,'']]],
@@ -55,9 +55,9 @@ var searchData=
   ['cellinsertmode_2eidl_52',['CellInsertMode.idl',['../CellInsertMode_8idl.html',1,'']]],
   ['celljustifymethod_2eidl_53',['CellJustifyMethod.idl',['../CellJustifyMethod_8idl.html',1,'']]],
   ['cellorientation_2eidl_54',['CellOrientation.idl',['../CellOrientation_8idl.html',1,'']]],
-  ['cellproperties_2eidl_55',['cellproperties.idl',['../text_2CellProperties_8idl.html',1,'(Global Namespace)'],['../table_2CellProperties_8idl.html',1,'(Global Namespace)']]],
+  ['cellproperties_2eidl_55',['CellProperties.idl',['../table_2CellProperties_8idl.html',1,'(Global Namespace)'],['../text_2CellProperties_8idl.html',1,'(Global Namespace)']]],
   ['cellprotection_2eidl_56',['CellProtection.idl',['../CellProtection_8idl.html',1,'']]],
-  ['cellrange_2eidl_57',['cellrange.idl',['../text_2CellRange_8idl.html',1,'(Global Namespace)'],['../table_2CellRange_8idl.html',1,'(Global Namespace)']]],
+  ['cellrange_2eidl_57',['CellRange.idl',['../table_2CellRange_8idl.html',1,'(Global Namespace)'],['../text_2CellRange_8idl.html',1,'(Global Namespace)']]],
   ['cellrangeaddress_2eidl_58',['CellRangeAddress.idl',['../CellRangeAddress_8idl.html',1,'']]],
   ['cellrangelistsource_2eidl_59',['CellRangeListSource.idl',['../CellRangeListSource_8idl.html',1,'']]],
   ['cells_2eidl_60',['Cells.idl',['../Cells_8idl.html',1,'']]],
@@ -119,7 +119,7 @@ var searchData=
   ['chartdatarowproperties_2eidl_116',['ChartDataRowProperties.idl',['../ChartDataRowProperties_8idl.html',1,'']]],
   ['chartdatarowsource_2eidl_117',['ChartDataRowSource.idl',['../ChartDataRowSource_8idl.html',1,'']]],
   ['chartdatavalue_2eidl_118',['ChartDataValue.idl',['../ChartDataValue_8idl.html',1,'']]],
-  ['chartdocument_2eidl_119',['chartdocument.idl',['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
+  ['chartdocument_2eidl_119',['ChartDocument.idl',['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
   ['chartdocumentwrapper_2eidl_120',['ChartDocumentWrapper.idl',['../ChartDocumentWrapper_8idl.html',1,'']]],
   ['charterrorcategory_2eidl_121',['ChartErrorCategory.idl',['../ChartErrorCategory_8idl.html',1,'']]],
   ['charterrorindicatortype_2eidl_122',['ChartErrorIndicatorType.idl',['../ChartErrorIndicatorType_8idl.html',1,'']]],
@@ -143,7 +143,7 @@ var searchData=
   ['charttypemanager_2eidl_140',['ChartTypeManager.idl',['../ChartTypeManager_8idl.html',1,'']]],
   ['charttypetemplate_2eidl_141',['ChartTypeTemplate.idl',['../ChartTypeTemplate_8idl.html',1,'']]],
   ['chartype_2eidl_142',['CharType.idl',['../CharType_8idl.html',1,'']]],
-  ['checkbox_2eidl_143',['checkbox.idl',['../component_2CheckBox_8idl.html',1,'(Global Namespace)'],['../control_2CheckBox_8idl.html',1,'(Global Namespace)']]],
+  ['checkbox_2eidl_143',['CheckBox.idl',['../component_2CheckBox_8idl.html',1,'(Global Namespace)'],['../control_2CheckBox_8idl.html',1,'(Global Namespace)']]],
   ['checkinargument_2eidl_144',['CheckinArgument.idl',['../CheckinArgument_8idl.html',1,'']]],
   ['checkoption_2eidl_145',['CheckOption.idl',['../CheckOption_8idl.html',1,'']]],
   ['cipherid_2eidl_146',['CipherID.idl',['../CipherID_8idl.html',1,'']]],
@@ -161,7 +161,7 @@ var searchData=
   ['cmisversion_2eidl_158',['CmisVersion.idl',['../CmisVersion_8idl.html',1,'']]],
   ['collator_2eidl_159',['Collator.idl',['../Collator_8idl.html',1,'']]],
   ['collatoroptions_2eidl_160',['CollatorOptions.idl',['../CollatorOptions_8idl.html',1,'']]],
-  ['color_2eidl_161',['color.idl',['../rendering_2Color_8idl.html',1,'(Global Namespace)'],['../util_2Color_8idl.html',1,'(Global Namespace)']]],
+  ['color_2eidl_161',['Color.idl',['../rendering_2Color_8idl.html',1,'(Global Namespace)'],['../util_2Color_8idl.html',1,'(Global Namespace)']]],
   ['colorcomponent_2eidl_162',['ColorComponent.idl',['../ColorComponent_8idl.html',1,'']]],
   ['colorcomponenttag_2eidl_163',['ColorComponentTag.idl',['../ColorComponentTag_8idl.html',1,'']]],
   ['colormode_2eidl_164',['ColorMode.idl',['../ColorMode_8idl.html',1,'']]],
@@ -170,54 +170,54 @@ var searchData=
   ['colorscale_2eidl_167',['ColorScale.idl',['../ColorScale_8idl.html',1,'']]],
   ['colorscaleentrytype_2eidl_168',['ColorScaleEntryType.idl',['../ColorScaleEntryType_8idl.html',1,'']]],
   ['colorspacetype_2eidl_169',['ColorSpaceType.idl',['../ColorSpaceType_8idl.html',1,'']]],
-  ['colortable_2eidl_170',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
-  ['column_2eidl_171',['column.idl',['../sdb_2Column_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Column_8idl.html',1,'(Global Namespace)']]],
-  ['columndescriptor_2eidl_172',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
-  ['columndescriptorcontrol_2eidl_173',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
-  ['columndescriptorcontrolmodel_2eidl_174',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
-  ['columnsearch_2eidl_175',['ColumnSearch.idl',['../ColumnSearch_8idl.html',1,'']]],
-  ['columnseparatorstyle_2eidl_176',['ColumnSeparatorStyle.idl',['../ColumnSeparatorStyle_8idl.html',1,'']]],
-  ['columnsettings_2eidl_177',['ColumnSettings.idl',['../ColumnSettings_8idl.html',1,'']]],
-  ['columntype_2eidl_178',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
-  ['columnvalue_2eidl_179',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
-  ['combinedcharacters_2eidl_180',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
-  ['combobox_2eidl_181',['combobox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
-  ['command_2eidl_182',['command.idl',['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)'],['../animations_2Command_8idl.html',1,'(Global Namespace)']]],
-  ['commandabortedexception_2eidl_183',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
-  ['commandbutton_2eidl_184',['commandbutton.idl',['../control_2CommandButton_8idl.html',1,'(Global Namespace)'],['../component_2CommandButton_8idl.html',1,'(Global Namespace)']]],
-  ['commanddefinition_2eidl_185',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
-  ['commandenvironment_2eidl_186',['CommandEnvironment.idl',['../CommandEnvironment_8idl.html',1,'']]],
-  ['commandfailedexception_2eidl_187',['CommandFailedException.idl',['../CommandFailedException_8idl.html',1,'']]],
-  ['commandgroup_2eidl_188',['CommandGroup.idl',['../CommandGroup_8idl.html',1,'']]],
-  ['commandinfo_2eidl_189',['CommandInfo.idl',['../CommandInfo_8idl.html',1,'']]],
-  ['commandinfochange_2eidl_190',['CommandInfoChange.idl',['../CommandInfoChange_8idl.html',1,'']]],
-  ['commandinfochangeevent_2eidl_191',['CommandInfoChangeEvent.idl',['../CommandInfoChangeEvent_8idl.html',1,'']]],
-  ['commandtype_2eidl_192',['CommandType.idl',['../CommandType_8idl.html',1,'']]],
-  ['commonfilepickerelementids_2eidl_193',['CommonFilePickerElementIds.idl',['../CommonFilePickerElementIds_8idl.html',1,'']]],
-  ['comparebookmark_2eidl_194',['CompareBookmark.idl',['../CompareBookmark_8idl.html',1,'']]],
-  ['complexreference_2eidl_195',['ComplexReference.idl',['../ComplexReference_8idl.html',1,'']]],
-  ['componentchangeevent_2eidl_196',['ComponentChangeEvent.idl',['../ComponentChangeEvent_8idl.html',1,'']]],
-  ['components_2eidl_197',['Components.idl',['../Components_8idl.html',1,'']]],
-  ['compositeoperation_2eidl_198',['CompositeOperation.idl',['../CompositeOperation_8idl.html',1,'']]],
-  ['compositiontype_2eidl_199',['CompositionType.idl',['../CompositionType_8idl.html',1,'']]],
-  ['conditionalformat_2eidl_200',['ConditionalFormat.idl',['../ConditionalFormat_8idl.html',1,'']]],
-  ['conditionaltext_2eidl_201',['ConditionalText.idl',['../ConditionalText_8idl.html',1,'']]],
-  ['conditionentrytype_2eidl_202',['ConditionEntryType.idl',['../ConditionEntryType_8idl.html',1,'']]],
-  ['conditionformatentry_2eidl_203',['ConditionFormatEntry.idl',['../ConditionFormatEntry_8idl.html',1,'']]],
-  ['conditionformatoperator_2eidl_204',['ConditionFormatOperator.idl',['../ConditionFormatOperator_8idl.html',1,'']]],
-  ['conditionoperator_2eidl_205',['ConditionOperator.idl',['../ConditionOperator_8idl.html',1,'']]],
-  ['conditionoperator2_2eidl_206',['ConditionOperator2.idl',['../ConditionOperator2_8idl.html',1,'']]],
-  ['configurableuielement_2eidl_207',['ConfigurableUIElement.idl',['../ConfigurableUIElement_8idl.html',1,'']]],
-  ['configuration_2eidl_208',['Configuration.idl',['../Configuration_8idl.html',1,'']]],
-  ['configurationaccess_2eidl_209',['ConfigurationAccess.idl',['../ConfigurationAccess_8idl.html',1,'']]],
-  ['configurationchangeevent_2eidl_210',['ConfigurationChangeEvent.idl',['../ConfigurationChangeEvent_8idl.html',1,'']]],
-  ['configurationcontroller_2eidl_211',['ConfigurationController.idl',['../ConfigurationController_8idl.html',1,'']]],
+  ['colorstop_2eidl_170',['ColorStop.idl',['../ColorStop_8idl.html',1,'']]],
+  ['colorstopsequence_2eidl_171',['ColorStopSequence.idl',['../ColorStopSequence_8idl.html',1,'']]],
+  ['colortable_2eidl_172',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
+  ['column_2eidl_173',['Column.idl',['../sdb_2Column_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Column_8idl.html',1,'(Global Namespace)']]],
+  ['columndescriptor_2eidl_174',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
+  ['columndescriptorcontrol_2eidl_175',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
+  ['columndescriptorcontrolmodel_2eidl_176',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
+  ['columnsearch_2eidl_177',['ColumnSearch.idl',['../ColumnSearch_8idl.html',1,'']]],
+  ['columnseparatorstyle_2eidl_178',['ColumnSeparatorStyle.idl',['../ColumnSeparatorStyle_8idl.html',1,'']]],
+  ['columnsettings_2eidl_179',['ColumnSettings.idl',['../ColumnSettings_8idl.html',1,'']]],
+  ['columntype_2eidl_180',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
+  ['columnvalue_2eidl_181',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
+  ['combinedcharacters_2eidl_182',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
+  ['combobox_2eidl_183',['ComboBox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
+  ['command_2eidl_184',['Command.idl',['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)']]],
+  ['commandabortedexception_2eidl_185',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
+  ['commandbutton_2eidl_186',['CommandButton.idl',['../component_2CommandButton_8idl.html',1,'(Global Namespace)'],['../control_2CommandButton_8idl.html',1,'(Global Namespace)']]],
+  ['commanddefinition_2eidl_187',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
+  ['commandenvironment_2eidl_188',['CommandEnvironment.idl',['../CommandEnvironment_8idl.html',1,'']]],
+  ['commandfailedexception_2eidl_189',['CommandFailedException.idl',['../CommandFailedException_8idl.html',1,'']]],
+  ['commandgroup_2eidl_190',['CommandGroup.idl',['../CommandGroup_8idl.html',1,'']]],
+  ['commandinfo_2eidl_191',['CommandInfo.idl',['../CommandInfo_8idl.html',1,'']]],
+  ['commandinfochange_2eidl_192',['CommandInfoChange.idl',['../CommandInfoChange_8idl.html',1,'']]],
+  ['commandinfochangeevent_2eidl_193',['CommandInfoChangeEvent.idl',['../CommandInfoChangeEvent_8idl.html',1,'']]],
+  ['commandtype_2eidl_194',['CommandType.idl',['../CommandType_8idl.html',1,'']]],
+  ['commonfilepickerelementids_2eidl_195',['CommonFilePickerElementIds.idl',['../CommonFilePickerElementIds_8idl.html',1,'']]],
+  ['comparebookmark_2eidl_196',['CompareBookmark.idl',['../CompareBookmark_8idl.html',1,'']]],
+  ['complexreference_2eidl_197',['ComplexReference.idl',['../ComplexReference_8idl.html',1,'']]],
+  ['componentchangeevent_2eidl_198',['ComponentChangeEvent.idl',['../ComponentChangeEvent_8idl.html',1,'']]],
+  ['components_2eidl_199',['Components.idl',['../Components_8idl.html',1,'']]],
+  ['compositeoperation_2eidl_200',['CompositeOperation.idl',['../CompositeOperation_8idl.html',1,'']]],
+  ['compositiontype_2eidl_201',['CompositionType.idl',['../CompositionType_8idl.html',1,'']]],
+  ['conditionalformat_2eidl_202',['ConditionalFormat.idl',['../ConditionalFormat_8idl.html',1,'']]],
+  ['conditionaltext_2eidl_203',['ConditionalText.idl',['../ConditionalText_8idl.html',1,'']]],
+  ['conditionentrytype_2eidl_204',['ConditionEntryType.idl',['../ConditionEntryType_8idl.html',1,'']]],
+  ['conditionformatentry_2eidl_205',['ConditionFormatEntry.idl',['../ConditionFormatEntry_8idl.html',1,'']]],
+  ['conditionformatoperator_2eidl_206',['ConditionFormatOperator.idl',['../ConditionFormatOperator_8idl.html',1,'']]],
+  ['conditionoperator_2eidl_207',['ConditionOperator.idl',['../ConditionOperator_8idl.html',1,'']]],
+  ['conditionoperator2_2eidl_208',['ConditionOperator2.idl',['../ConditionOperator2_8idl.html',1,'']]],
+  ['configurableuielement_2eidl_209',['ConfigurableUIElement.idl',['../ConfigurableUIElement_8idl.html',1,'']]],
+  ['configurationaccess_2eidl_210',['ConfigurationAccess.idl',['../ConfigurationAccess_8idl.html',1,'']]],
+  ['configurationchangeevent_2eidl_211',['ConfigurationChangeEvent.idl',['../ConfigurationChangeEvent_8idl.html',1,'']]],
   ['configurationevent_2eidl_212',['ConfigurationEvent.idl',['../ConfigurationEvent_8idl.html',1,'']]],
   ['configurationprovider_2eidl_213',['ConfigurationProvider.idl',['../ConfigurationProvider_8idl.html',1,'']]],
   ['configurationregistry_2eidl_214',['ConfigurationRegistry.idl',['../ConfigurationRegistry_8idl.html',1,'']]],
   ['configurationupdateaccess_2eidl_215',['ConfigurationUpdateAccess.idl',['../ConfigurationUpdateAccess_8idl.html',1,'']]],
   ['connectexception_2eidl_216',['ConnectException.idl',['../ConnectException_8idl.html',1,'']]],
-  ['connection_2eidl_217',['connection.idl',['../sdb_2Connection_8idl.html',1,'(Global Namespace)'],['../sdbc_2Connection_8idl.html',1,'(Global Namespace)']]],
+  ['connection_2eidl_217',['Connection.idl',['../sdb_2Connection_8idl.html',1,'(Global Namespace)'],['../sdbc_2Connection_8idl.html',1,'(Global Namespace)']]],
   ['connectionlostexception_2eidl_218',['ConnectionLostException.idl',['../ConnectionLostException_8idl.html',1,'']]],
   ['connectionmode_2eidl_219',['ConnectionMode.idl',['../ConnectionMode_8idl.html',1,'']]],
   ['connectionpool_2eidl_220',['ConnectionPool.idl',['../ConnectionPool_8idl.html',1,'']]],
@@ -231,75 +231,77 @@ var searchData=
   ['connectortype_2eidl_228',['ConnectorType.idl',['../ConnectorType_8idl.html',1,'']]],
   ['consolehandler_2eidl_229',['ConsoleHandler.idl',['../ConsoleHandler_8idl.html',1,'']]],
   ['consolidationdescriptor_2eidl_230',['ConsolidationDescriptor.idl',['../ConsolidationDescriptor_8idl.html',1,'']]],
-  ['constofsecurityid_2eidl_231',['ConstOfSecurityId.idl',['../ConstOfSecurityId_8idl.html',1,'']]],
-  ['container_2eidl_232',['Container.idl',['../Container_8idl.html',1,'']]],
-  ['containerevent_2eidl_233',['ContainerEvent.idl',['../ContainerEvent_8idl.html',1,'']]],
-  ['containerwindowprovider_2eidl_234',['ContainerWindowProvider.idl',['../ContainerWindowProvider_8idl.html',1,'']]],
-  ['content_2eidl_235',['Content.idl',['../Content_8idl.html',1,'']]],
-  ['contentaction_2eidl_236',['ContentAction.idl',['../ContentAction_8idl.html',1,'']]],
-  ['contentcontrol_2eidl_237',['ContentControl.idl',['../ContentControl_8idl.html',1,'']]],
-  ['contentcreationerror_2eidl_238',['ContentCreationError.idl',['../ContentCreationError_8idl.html',1,'']]],
-  ['contentcreationexception_2eidl_239',['ContentCreationException.idl',['../ContentCreationException_8idl.html',1,'']]],
-  ['contentevent_2eidl_240',['ContentEvent.idl',['../ContentEvent_8idl.html',1,'']]],
-  ['contenthandler_2eidl_241',['ContentHandler.idl',['../ContentHandler_8idl.html',1,'']]],
-  ['contenthandlerfactory_2eidl_242',['ContentHandlerFactory.idl',['../ContentHandlerFactory_8idl.html',1,'']]],
-  ['contentindex_2eidl_243',['ContentIndex.idl',['../ContentIndex_8idl.html',1,'']]],
-  ['contentindexmark_2eidl_244',['ContentIndexMark.idl',['../ContentIndexMark_8idl.html',1,'']]],
-  ['contentinfo_2eidl_245',['ContentInfo.idl',['../ContentInfo_8idl.html',1,'']]],
-  ['contentinfoattribute_2eidl_246',['ContentInfoAttribute.idl',['../ContentInfoAttribute_8idl.html',1,'']]],
-  ['contentloader_2eidl_247',['ContentLoader.idl',['../ContentLoader_8idl.html',1,'']]],
-  ['contentprovider_2eidl_248',['ContentProvider.idl',['../ContentProvider_8idl.html',1,'']]],
-  ['contentproviderinfo_2eidl_249',['ContentProviderInfo.idl',['../ContentProviderInfo_8idl.html',1,'']]],
-  ['contentproviderproxy_2eidl_250',['ContentProviderProxy.idl',['../ContentProviderProxy_8idl.html',1,'']]],
-  ['contentproviderproxyfactory_2eidl_251',['ContentProviderProxyFactory.idl',['../ContentProviderProxyFactory_8idl.html',1,'']]],
-  ['contentresultset_2eidl_252',['ContentResultSet.idl',['../ContentResultSet_8idl.html',1,'']]],
-  ['contentresultsetcapability_2eidl_253',['ContentResultSetCapability.idl',['../ContentResultSetCapability_8idl.html',1,'']]],
-  ['contenttransmitter_2eidl_254',['ContentTransmitter.idl',['../ContentTransmitter_8idl.html',1,'']]],
-  ['contextchangeeventmultiplexer_2eidl_255',['ContextChangeEventMultiplexer.idl',['../ContextChangeEventMultiplexer_8idl.html',1,'']]],
-  ['contextchangeeventobject_2eidl_256',['ContextChangeEventObject.idl',['../ContextChangeEventObject_8idl.html',1,'']]],
-  ['contextinformation_2eidl_257',['ContextInformation.idl',['../ContextInformation_8idl.html',1,'']]],
-  ['contextmenuexecuteevent_2eidl_258',['ContextMenuExecuteEvent.idl',['../ContextMenuExecuteEvent_8idl.html',1,'']]],
-  ['contextmenuinterceptoraction_2eidl_259',['ContextMenuInterceptorAction.idl',['../ContextMenuInterceptorAction_8idl.html',1,'']]],
-  ['controlactions_2eidl_260',['ControlActions.idl',['../ControlActions_8idl.html',1,'']]],
-  ['controlcharacter_2eidl_261',['ControlCharacter.idl',['../ControlCharacter_8idl.html',1,'']]],
-  ['controlcommand_2eidl_262',['ControlCommand.idl',['../ControlCommand_8idl.html',1,'']]],
-  ['controlevent_2eidl_263',['ControlEvent.idl',['../ControlEvent_8idl.html',1,'']]],
-  ['controlfontdialog_2eidl_264',['ControlFontDialog.idl',['../ControlFontDialog_8idl.html',1,'']]],
-  ['controller_2eidl_265',['Controller.idl',['../Controller_8idl.html',1,'']]],
-  ['controlshape_2eidl_266',['ControlShape.idl',['../ControlShape_8idl.html',1,'']]],
-  ['conversiondictionary_2eidl_267',['ConversionDictionary.idl',['../ConversionDictionary_8idl.html',1,'']]],
-  ['conversiondictionarylist_2eidl_268',['ConversionDictionaryList.idl',['../ConversionDictionaryList_8idl.html',1,'']]],
-  ['conversiondictionarytype_2eidl_269',['ConversionDictionaryType.idl',['../ConversionDictionaryType_8idl.html',1,'']]],
-  ['conversiondirection_2eidl_270',['ConversionDirection.idl',['../ConversionDirection_8idl.html',1,'']]],
-  ['conversionpropertytype_2eidl_271',['ConversionPropertyType.idl',['../ConversionPropertyType_8idl.html',1,'']]],
-  ['converter_2eidl_272',['Converter.idl',['../Converter_8idl.html',1,'']]],
-  ['coordinatesequence_2eidl_273',['CoordinateSequence.idl',['../CoordinateSequence_8idl.html',1,'']]],
-  ['coordinatesequencesequence_2eidl_274',['CoordinateSequenceSequence.idl',['../CoordinateSequenceSequence_8idl.html',1,'']]],
-  ['coordinatesystem_2eidl_275',['CoordinateSystem.idl',['../CoordinateSystem_8idl.html',1,'']]],
-  ['coordinatesystemtype_2eidl_276',['CoordinateSystemType.idl',['../CoordinateSystemType_8idl.html',1,'']]],
-  ['coordinatesystemtypeid_2eidl_277',['CoordinateSystemTypeID.idl',['../CoordinateSystemTypeID_8idl.html',1,'']]],
-  ['copyimporter_2eidl_278',['CopyImporter.idl',['../CopyImporter_8idl.html',1,'']]],
-  ['copytablecontinuation_2eidl_279',['CopyTableContinuation.idl',['../CopyTableContinuation_8idl.html',1,'']]],
-  ['copytableoperation_2eidl_280',['CopyTableOperation.idl',['../CopyTableOperation_8idl.html',1,'']]],
-  ['copytablerowevent_2eidl_281',['CopyTableRowEvent.idl',['../CopyTableRowEvent_8idl.html',1,'']]],
-  ['copytablewizard_2eidl_282',['CopyTableWizard.idl',['../CopyTableWizard_8idl.html',1,'']]],
-  ['corereflection_2eidl_283',['CoreReflection.idl',['../CoreReflection_8idl.html',1,'']]],
-  ['corruptedconfigurationexception_2eidl_284',['CorruptedConfigurationException.idl',['../CorruptedConfigurationException_8idl.html',1,'']]],
-  ['corruptedfilterconfigurationexception_2eidl_285',['CorruptedFilterConfigurationException.idl',['../CorruptedFilterConfigurationException_8idl.html',1,'']]],
-  ['corrupteduiconfigurationexception_2eidl_286',['CorruptedUIConfigurationException.idl',['../CorruptedUIConfigurationException_8idl.html',1,'']]],
-  ['createauthor_2eidl_287',['CreateAuthor.idl',['../CreateAuthor_8idl.html',1,'']]],
-  ['createdatetime_2eidl_288',['CreateDateTime.idl',['../CreateDateTime_8idl.html',1,'']]],
-  ['crossreference_2eidl_289',['CrossReference.idl',['../CrossReference_8idl.html',1,'']]],
-  ['cryptographyexception_2eidl_290',['CryptographyException.idl',['../CryptographyException_8idl.html',1,'']]],
-  ['csvlogformatter_2eidl_291',['CsvLogFormatter.idl',['../CsvLogFormatter_8idl.html',1,'']]],
-  ['ctlscripttype_2eidl_292',['CTLScriptType.idl',['../CTLScriptType_8idl.html',1,'']]],
-  ['currency_2eidl_293',['currency.idl',['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)']]],
-  ['currency2_2eidl_294',['Currency2.idl',['../Currency2_8idl.html',1,'']]],
-  ['currencyfield_2eidl_295',['currencyfield.idl',['../control_2CurrencyField_8idl.html',1,'(Global Namespace)'],['../component_2CurrencyField_8idl.html',1,'(Global Namespace)']]],
-  ['curvestyle_2eidl_296',['CurveStyle.idl',['../CurveStyle_8idl.html',1,'']]],
-  ['custom_2eidl_297',['Custom.idl',['../Custom_8idl.html',1,'']]],
-  ['custompresentation_2eidl_298',['CustomPresentation.idl',['../CustomPresentation_8idl.html',1,'']]],
-  ['custompresentationaccess_2eidl_299',['CustomPresentationAccess.idl',['../CustomPresentationAccess_8idl.html',1,'']]],
-  ['customshape_2eidl_300',['CustomShape.idl',['../CustomShape_8idl.html',1,'']]],
-  ['customshapeengine_2eidl_301',['CustomShapeEngine.idl',['../CustomShapeEngine_8idl.html',1,'']]]
+  ['constants_2eidl_231',['Constants.idl',['../Constants_8idl.html',1,'']]],
+  ['constofsecurityid_2eidl_232',['ConstOfSecurityId.idl',['../ConstOfSecurityId_8idl.html',1,'']]],
+  ['container_2eidl_233',['Container.idl',['../Container_8idl.html',1,'']]],
+  ['containerevent_2eidl_234',['ContainerEvent.idl',['../ContainerEvent_8idl.html',1,'']]],
+  ['containerwindowprovider_2eidl_235',['ContainerWindowProvider.idl',['../ContainerWindowProvider_8idl.html',1,'']]],
+  ['content_2eidl_236',['Content.idl',['../Content_8idl.html',1,'']]],
+  ['contentaction_2eidl_237',['ContentAction.idl',['../ContentAction_8idl.html',1,'']]],
+  ['contentcontrol_2eidl_238',['ContentControl.idl',['../ContentControl_8idl.html',1,'']]],
+  ['contentcreationerror_2eidl_239',['ContentCreationError.idl',['../ContentCreationError_8idl.html',1,'']]],
+  ['contentcreationexception_2eidl_240',['ContentCreationException.idl',['../ContentCreationException_8idl.html',1,'']]],
+  ['contentevent_2eidl_241',['ContentEvent.idl',['../ContentEvent_8idl.html',1,'']]],
+  ['contenthandler_2eidl_242',['ContentHandler.idl',['../ContentHandler_8idl.html',1,'']]],
+  ['contenthandlerfactory_2eidl_243',['ContentHandlerFactory.idl',['../ContentHandlerFactory_8idl.html',1,'']]],
+  ['contentindex_2eidl_244',['ContentIndex.idl',['../ContentIndex_8idl.html',1,'']]],
+  ['contentindexmark_2eidl_245',['ContentIndexMark.idl',['../ContentIndexMark_8idl.html',1,'']]],
+  ['contentinfo_2eidl_246',['ContentInfo.idl',['../ContentInfo_8idl.html',1,'']]],
+  ['contentinfoattribute_2eidl_247',['ContentInfoAttribute.idl',['../ContentInfoAttribute_8idl.html',1,'']]],
+  ['contentloader_2eidl_248',['ContentLoader.idl',['../ContentLoader_8idl.html',1,'']]],
+  ['contentprovider_2eidl_249',['ContentProvider.idl',['../ContentProvider_8idl.html',1,'']]],
+  ['contentproviderinfo_2eidl_250',['ContentProviderInfo.idl',['../ContentProviderInfo_8idl.html',1,'']]],
+  ['contentproviderproxy_2eidl_251',['ContentProviderProxy.idl',['../ContentProviderProxy_8idl.html',1,'']]],
+  ['contentproviderproxyfactory_2eidl_252',['ContentProviderProxyFactory.idl',['../ContentProviderProxyFactory_8idl.html',1,'']]],
+  ['contentresultset_2eidl_253',['ContentResultSet.idl',['../ContentResultSet_8idl.html',1,'']]],
+  ['contentresultsetcapability_2eidl_254',['ContentResultSetCapability.idl',['../ContentResultSetCapability_8idl.html',1,'']]],
+  ['contenttransmitter_2eidl_255',['ContentTransmitter.idl',['../ContentTransmitter_8idl.html',1,'']]],
+  ['contextchangeeventmultiplexer_2eidl_256',['ContextChangeEventMultiplexer.idl',['../ContextChangeEventMultiplexer_8idl.html',1,'']]],
+  ['contextchangeeventobject_2eidl_257',['ContextChangeEventObject.idl',['../ContextChangeEventObject_8idl.html',1,'']]],
+  ['contextinformation_2eidl_258',['ContextInformation.idl',['../ContextInformation_8idl.html',1,'']]],
+  ['contextmenuexecuteevent_2eidl_259',['ContextMenuExecuteEvent.idl',['../ContextMenuExecuteEvent_8idl.html',1,'']]],
+  ['contextmenuinterceptoraction_2eidl_260',['ContextMenuInterceptorAction.idl',['../ContextMenuInterceptorAction_8idl.html',1,'']]],
+  ['controlactions_2eidl_261',['ControlActions.idl',['../ControlActions_8idl.html',1,'']]],
+  ['controlcharacter_2eidl_262',['ControlCharacter.idl',['../ControlCharacter_8idl.html',1,'']]],
+  ['controlcommand_2eidl_263',['ControlCommand.idl',['../ControlCommand_8idl.html',1,'']]],
+  ['controlevent_2eidl_264',['ControlEvent.idl',['../ControlEvent_8idl.html',1,'']]],
+  ['controlfontdialog_2eidl_265',['ControlFontDialog.idl',['../ControlFontDialog_8idl.html',1,'']]],
+  ['controller_2eidl_266',['Controller.idl',['../Controller_8idl.html',1,'']]],
+  ['controlshape_2eidl_267',['ControlShape.idl',['../ControlShape_8idl.html',1,'']]],
+  ['conversiondictionary_2eidl_268',['ConversionDictionary.idl',['../ConversionDictionary_8idl.html',1,'']]],
+  ['conversiondictionarylist_2eidl_269',['ConversionDictionaryList.idl',['../ConversionDictionaryList_8idl.html',1,'']]],
+  ['conversiondictionarytype_2eidl_270',['ConversionDictionaryType.idl',['../ConversionDictionaryType_8idl.html',1,'']]],
+  ['conversiondirection_2eidl_271',['ConversionDirection.idl',['../ConversionDirection_8idl.html',1,'']]],
+  ['conversionpropertytype_2eidl_272',['ConversionPropertyType.idl',['../ConversionPropertyType_8idl.html',1,'']]],
+  ['converter_2eidl_273',['Converter.idl',['../Converter_8idl.html',1,'']]],
+  ['coordinatesequence_2eidl_274',['CoordinateSequence.idl',['../CoordinateSequence_8idl.html',1,'']]],
+  ['coordinatesequencesequence_2eidl_275',['CoordinateSequenceSequence.idl',['../CoordinateSequenceSequence_8idl.html',1,'']]],
+  ['coordinatesystem_2eidl_276',['CoordinateSystem.idl',['../CoordinateSystem_8idl.html',1,'']]],
+  ['coordinatesystemtype_2eidl_277',['CoordinateSystemType.idl',['../CoordinateSystemType_8idl.html',1,'']]],
+  ['coordinatesystemtypeid_2eidl_278',['CoordinateSystemTypeID.idl',['../CoordinateSystemTypeID_8idl.html',1,'']]],
+  ['copyimporter_2eidl_279',['CopyImporter.idl',['../CopyImporter_8idl.html',1,'']]],
+  ['copytablecontinuation_2eidl_280',['CopyTableContinuation.idl',['../CopyTableContinuation_8idl.html',1,'']]],
+  ['copytableoperation_2eidl_281',['CopyTableOperation.idl',['../CopyTableOperation_8idl.html',1,'']]],
+  ['copytablerowevent_2eidl_282',['CopyTableRowEvent.idl',['../CopyTableRowEvent_8idl.html',1,'']]],
+  ['copytablewizard_2eidl_283',['CopyTableWizard.idl',['../CopyTableWizard_8idl.html',1,'']]],
+  ['corereflection_2eidl_284',['CoreReflection.idl',['../CoreReflection_8idl.html',1,'']]],
+  ['corruptedconfigurationexception_2eidl_285',['CorruptedConfigurationException.idl',['../CorruptedConfigurationException_8idl.html',1,'']]],
+  ['corruptedfilterconfigurationexception_2eidl_286',['CorruptedFilterConfigurationException.idl',['../CorruptedFilterConfigurationException_8idl.html',1,'']]],
+  ['corrupteduiconfigurationexception_2eidl_287',['CorruptedUIConfigurationException.idl',['../CorruptedUIConfigurationException_8idl.html',1,'']]],
+  ['createauthor_2eidl_288',['CreateAuthor.idl',['../CreateAuthor_8idl.html',1,'']]],
+  ['createdatetime_2eidl_289',['CreateDateTime.idl',['../CreateDateTime_8idl.html',1,'']]],
+  ['createdialogfactoryservice_2eidl_290',['CreateDialogFactoryService.idl',['../presentation_2CreateDialogFactoryService_8idl.html',1,'(Global Namespace)'],['../sheet_2CreateDialogFactoryService_8idl.html',1,'(Global Namespace)']]],
+  ['crossreference_2eidl_291',['CrossReference.idl',['../CrossReference_8idl.html',1,'']]],
+  ['cryptographyexception_2eidl_292',['CryptographyException.idl',['../CryptographyException_8idl.html',1,'']]],
+  ['csvlogformatter_2eidl_293',['CsvLogFormatter.idl',['../CsvLogFormatter_8idl.html',1,'']]],
+  ['ctlscripttype_2eidl_294',['CTLScriptType.idl',['../CTLScriptType_8idl.html',1,'']]],
+  ['currency_2eidl_295',['Currency.idl',['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)']]],
+  ['currency2_2eidl_296',['Currency2.idl',['../Currency2_8idl.html',1,'']]],
+  ['currencyfield_2eidl_297',['CurrencyField.idl',['../component_2CurrencyField_8idl.html',1,'(Global Namespace)'],['../control_2CurrencyField_8idl.html',1,'(Global Namespace)']]],
+  ['curvestyle_2eidl_298',['CurveStyle.idl',['../CurveStyle_8idl.html',1,'']]],
+  ['custom_2eidl_299',['Custom.idl',['../Custom_8idl.html',1,'']]],
+  ['custompresentation_2eidl_300',['CustomPresentation.idl',['../CustomPresentation_8idl.html',1,'']]],
+  ['custompresentationaccess_2eidl_301',['CustomPresentationAccess.idl',['../CustomPresentationAccess_8idl.html',1,'']]],
+  ['customshape_2eidl_302',['CustomShape.idl',['../CustomShape_8idl.html',1,'']]],
+  ['customshapeengine_2eidl_303',['CustomShapeEngine.idl',['../CustomShapeEngine_8idl.html',1,'']]]
 ];
