@@ -1,5 +1,5 @@
 var servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape =
 [
-    [ "Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape.html#a337a0b131cd17ef2c08b51d5b37e04ef", null ],
+    [ "com::sun::star::drawing::Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape.html#a337a0b131cd17ef2c08b51d5b37e04ef", null ],
     [ "PageNumber", "servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape.html#af0e72cfd976d2542aef7c3f3ee8c1f1a", null ]
 ];
\ No newline at end of file
